@@ -1,4 +1,4 @@
-version = VERSION = __version__ = "0.0.1"
+version = VERSION = __version__ = "0.0.2"
 
 def gcovparse(combined):
     # clean and strip lines
@@ -26,4 +26,4 @@ def _line(l, report):
         elif data.startswith("Programs"):
             report["stats"]["programs"] = data[9:]
         elif int(line) > 0:
-            report['lines'].append(dict(line=line.strip(), hit=None if '-' in hit else 0 if '#' in hit else hit.strip()))
+            report['lines'].append(dict(line=int(line.strip()), hit=None if '-' in hit else 0 if '#' in hit else int(hit.strip())))
